@@ -35,7 +35,7 @@
 CK_RV
 gkm_attribute_get_bool (CK_ATTRIBUTE_PTR attr, gboolean *value)
 {
-	CK_BBOOL* bool;
+	CK_BBOOL* booly;
 
 	g_return_val_if_fail (attr, CKR_GENERAL_ERROR);
 	g_return_val_if_fail (value, CKR_GENERAL_ERROR);
@@ -43,8 +43,8 @@ gkm_attribute_get_bool (CK_ATTRIBUTE_PTR attr, gboolean *value)
 	if (attr->ulValueLen != sizeof (CK_BBOOL) || attr->pValue == NULL)
 		return CKR_ATTRIBUTE_VALUE_INVALID;
 
-	bool = attr->pValue;
-	*value = *bool ? TRUE : FALSE;
+	booly = attr->pValue;
+	*value = *booly ? TRUE : FALSE;
 	return CKR_OK;
 }
 
