@@ -78,7 +78,7 @@ static GQuark TRUST_TRUSTED_ANCHOR;
 static void
 init_quarks (void)
 {
-	static volatile gsize quarks_inited = 0;
+	static gsize quarks_inited = 0;
 
 	if (g_once_init_enter (&quarks_inited)) {
 
